==> bee-ui-0.0.33.tgz: package/src/TabScene/index.js <==
import React, {
  PropTypes,
  Component,
  ViewPropTypes,
  ViewStylePropTypes,
} from 'react';
import {
  View,
  Text,
  Animated,
  Dimensions,
  StyleSheet,
} from 'react-native';
import DefaultTabBar from '../TabBar';
import SceneComponent from './Scene';


const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  activeTextStyle: {
    color: '#82A0FA',
  },
  tabDeafultText: {
    color: '#888',
  },
  tabBackground: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingBottom: 10,
  },
  scrollContent: {
    flex: 1,
    flexDirection: 'row',
  },
});

class TabScene extends Component {
  static propTypes = {
    tabBarPosition: PropTypes.oneOf(['top', 'bottom', 'overlayTop', 'overlayBottom']),
    initialPage: PropTypes.number,
    page: PropTypes.number,
    onChangeTab: PropTypes.func,
    renderTabBar: PropTypes.func,
    activeTextStyle: Text.propTypes.style,
    defaultTextStyle: Text.propTypes.style,
    tabBarStyle: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
    tabUnderLineStyle: ViewStylePropTypes || (View.propTypes && View.propTypes.style), // 下划线背景
    children: PropTypes.array,
  }
  static defaultProps = {
    tabBarPosition: 'top',
    initialPage: 0,
    page: -1,
    onChangeTab: () => {},
    tabBarStyle: null,
    tabUnderLineStyle: null,
    defaultTextStyle: styles.defaultTextStyle,
    activeTextStyle: styles.activeTextStyle,
    style: null,
    renderTabBar: null,
    children: [],
  }
  constructor(props) {
    super(props);
    this.state = {
      currentPage: props.initialPage,
      containerWidth: Dimensions.get('window').width,
      fadeAnim: new Animated.Value(0),
      len: this.props.children.length,
    };
  }
  componentWillReceiveProps = (props) => {
    if (props.page >= 0 && props.page !== this.state.currentPage) {
      this.goToPage(props.page);
    }
  }
  _children = (children = this.props.children) => React.Children.map(children, child => child);

  goToScene = (pageNumber) => {
    const offset = pageNumber * this.state.containerWidth;
    const currentPage = this.state.currentPage;
    this.updateSceneKeys({
      page: pageNumber,
      callback: this._onChangeTab.bind(this, currentPage, pageNumber),
    });
    Animated.spring(
      this.state.fadeAnim,
      {
        toValue: -offset,
      },
    ).start();
  }
  updateSceneKeys = ({ page, children = this.props.children, callback = () => {} }) => {
    this.setState({ currentPage: page }, callback);
  }

  _onChangeTab = (prevPage, currentPage) => {
    this.props.onChangeTab({
      i: currentPage,
      ref: this._children()[currentPage],
      from: prevPage,
    });
  }
  renderScrollableContent = () => this._children().map((child, idx, children) => {
    const tabLabel = child.props.tabLabel;
    return (
      <SceneComponent
        key={child.key}
        style={child.props.style}
      >
        {child}
      </SceneComponent>
    );
  });


  renderTabBar = (props) => {
    if (this.props.renderTabBar === false) {
      return null;
    } else if (this.props.renderTabBar) {
      return React.cloneElement(this.props.renderTabBar(props), props);
    }
    return <DefaultTabBar {...props} style={{ height: 30 }} />;
  }

  get tabBarProps() {
    return {
      goToScene: this.goToScene,
      tabs: this._children().map(child => child.props.tabLabel),
      activeTab: this.state.currentPage,
      activeTextStyle: this.props.activeTextStyle,
      defaultTextStyle: this.props.defaultTextStyle,
      tabUnderLineStyle: this.props.tabUnderLineStyle,
      tabBarStyle: this.props.tabBarStyle,
    };
  }

  render() {
    return (
      <View style={styles.container}>
        {this.props.tabBarPosition === 'top' && this.renderTabBar(this.tabBarProps)}
        <View style={{ flex: 1, flexDirection: 'row', width: this.state.containerWidth * this.state.len }}>
          <Animated.View
            style={[styles.scrollContent, { width: this.state.containerWidth }, {
              transform: [
                { translateX: this.state.fadeAnim },
              ],
            }]}
          >
            {this.renderScrollableContent()}
          </Animated.View>
        </View>
      </View>
    );
  }
}
export default TabScene;

==> bee-ui-0.0.35.tgz: package/src/TabScene/index.js <==
import React, {
  Component, PropTypes, ViewStylePropTypes,
} from 'react';

import {
  Animated, Dimensions, Text, View,
} from 'react-native';

import DefaultTabBar from '../TabBar';
import SceneComponent from './Scene';

const styles = {
  container: {
    flex: 1,
  },
  activeTextStyle: {
    color: '#82A0FA',
  },
  tabDeafultText: {
    color: '#888',
  },
  tabBackground: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
    paddingBottom: 10,
  },
  scrollContent: {
    flex: 1,
    flexDirection: 'row',
  },
};

const propTypes = {
  tabBarPosition: PropTypes.oneOf(['top', 'bottom', 'overlayTop', 'overlayBottom']),
  initialPage: PropTypes.number,
  page: PropTypes.number,
  onChangeTab: PropTypes.func,
  renderTabBar: PropTypes.func,
  activeTextStyle: Text.propTypes.style,
  defaultTextStyle: Text.propTypes.style,
  tabBarStyle: ViewStylePropTypes || (View.propTypes && View.propTypes.style),
  tabUnderLineStyle: ViewStylePropTypes || (View.propTypes && View.propTypes.style), // 下划线背景
  children: PropTypes.array,
};
const defaultProps = {
  tabBarPosition: 'top',
  initialPage: 0,
  page: -1,
  onChangeTab: () => {},
  tabBarStyle: null,
  tabUnderLineStyle: null,
  defaultTextStyle: styles.defaultTextStyle,
  activeTextStyle: styles.activeTextStyle,
  style: null,
  renderTabBar: null,
  children: [],
};

class TabScene extends Component {
  constructor(props) {
    super(props);
    this.state = {
      currentPage: props.initialPage,
      containerWidth: Dimensions.get('window').width,
      fadeAnim: new Animated.Value(0),
      len: this.props.children.length,
    };
  }

  componentWillReceiveProps = (props) => {
    if (props.page >= 0 && props.page !== this.state.currentPage) {
      this.goToPage(props.page);
    }
  }

  get tabBarProps() {
    return {
      goToScene: this.goToScene,
      tabs: this.getChildren().map(child => child.props.tabLabel),
      activeTab: this.state.currentPage,
      activeTextStyle: this.props.activeTextStyle,
      defaultTextStyle: this.props.defaultTextStyle,
      tabUnderLineStyle: this.props.tabUnderLineStyle,
      tabBarStyle: this.props.tabBarStyle,
    };
  }

  getChildren = (children = this.props.children) => React.Children.map(children, child => child);

  goToScene = (pageNumber) => {
    const offset = pageNumber * this.state.containerWidth;
    const currentPage = this.state.currentPage;
    this.updateSceneKeys({
      page: pageNumber,
      callback: this.handleChangeTab.bind(this, currentPage, pageNumber),
    });
    Animated.spring(
      this.state.fadeAnim,
      {
        toValue: -offset,
      },
    ).start();
  }
  updateSceneKeys = ({ page, callback = () => {} }) => {
    this.setState({ currentPage: page }, callback);
  }

  handleChangeTab = (prevPage, currentPage) => {
    this.props.onChangeTab({
      i: currentPage,
      ref: this.getChildren()[currentPage],
      from: prevPage,
    });
  }

  renderScrollableContent = () => this.getChildren().map((child => (
    <SceneComponent
      key={child.key}
      style={child.props.style}
    >
      {child}
    </SceneComponent>
  )));

  renderTabBar = (props) => {
    if (this.props.renderTabBar === false) {
      return null;
    } else if (this.props.renderTabBar) {
      return React.cloneElement(this.props.renderTabBar(props), props);
    }
    return <DefaultTabBar {...props} style={{ height: 30 }} />;
  }

  render() {
    return (
      <View style={styles.container}>
        {this.props.tabBarPosition === 'top' && this.renderTabBar(this.tabBarProps)}
        <View style={{ flex: 1, flexDirection: 'row', width: this.state.containerWidth * this.state.len }}>
          <Animated.View
            style={[styles.scrollContent, { width: this.state.containerWidth }, {
              transform: [
                { translateX: this.state.fadeAnim },
              ],
            }]}
          >
            {this.renderScrollableContent()}
          </Animated.View>
        </View>
      </View>
    );
  }
}

TabScene.propTypes = propTypes;
TabScene.defaultProps = defaultProps;

export default TabScene;
